package kr.co.vividnext.sodalive.audio_content.playlist

import android.annotation.SuppressLint
import android.content.Intent
import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import kr.co.vividnext.sodalive.audio_content.playlist.detail.AudioContentPlaylistDetailActivity
import kr.co.vividnext.sodalive.base.BaseFragment
import kr.co.vividnext.sodalive.common.Constants
import kr.co.vividnext.sodalive.common.LoadingDialog
import kr.co.vividnext.sodalive.databinding.FragmentAudioContentPlaylistListBinding
import org.koin.android.ext.android.inject

class AudioContentPlaylistListFragment : BaseFragment<FragmentAudioContentPlaylistListBinding>(
    FragmentAudioContentPlaylistListBinding::inflate
) {

    private val viewModel: AudioContentPlaylistListViewModel by inject()

    private lateinit var loadingDialog: LoadingDialog
    private lateinit var adapter: AudioContentPlaylistListAdapter

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        setupView()
        bindData()

        viewModel.getPlaylistList()
    }

    private fun setupView() {
        loadingDialog = LoadingDialog(requireActivity(), layoutInflater)
        adapter = AudioContentPlaylistListAdapter { playlistId ->
            startActivity(
                Intent(requireContext(), AudioContentPlaylistDetailActivity::class.java).apply {
                    putExtra(
                        Constants.EXTRA_AUDIO_CONTENT_PLAYLIST_ID,
                        playlistId
                    )
                }
            )
        }

        val recyclerView = binding.rvPlaylistList
        recyclerView.setHasFixedSize(true)
        recyclerView.layoutManager = LinearLayoutManager(
            activity,
            LinearLayoutManager.VERTICAL,
            false
        )
        recyclerView.adapter = adapter
    }

    @SuppressLint("SetTextI18n")
    private fun bindData() {
        viewModel.isLoading.observe(viewLifecycleOwner) {
            if (it) {
                loadingDialog.show(screenWidth)
            } else {
                loadingDialog.dismiss()
            }
        }

        viewModel.toastLiveData.observe(viewLifecycleOwner) {
            it?.let { showToast(it) }
        }

        viewModel.totalCountLiveData.observe(viewLifecycleOwner) {
            binding.tvTotalCount.text = "${it}개"
        }

        viewModel.playlistLiveData.observe(viewLifecycleOwner) {
            if (it.isEmpty()) {
                binding.tvTotalCount.visibility = View.GONE
                binding.rvPlaylistList.visibility = View.GONE
                binding.llNoPlaylist.visibility = View.VISIBLE
            } else {
                binding.llNoPlaylist.visibility = View.GONE
                binding.tvTotalCount.visibility = View.VISIBLE
                binding.rvPlaylistList.visibility = View.VISIBLE

                adapter.items.addAll(it)
            }
        }
    }
}
