package kr.co.vividnext.sodalive.audio_content.playlist.detail

import android.annotation.SuppressLint
import android.os.Bundle
import android.view.View
import android.widget.ImageView
import android.widget.Toast
import androidx.recyclerview.widget.LinearLayoutManager
import coil.load
import kr.co.vividnext.sodalive.base.BaseActivity
import kr.co.vividnext.sodalive.common.Constants
import kr.co.vividnext.sodalive.common.LoadingDialog
import kr.co.vividnext.sodalive.databinding.ActivityAudioContentPlaylistDetailBinding
import org.koin.android.ext.android.inject

class AudioContentPlaylistDetailActivity : BaseActivity<ActivityAudioContentPlaylistDetailBinding>(
    ActivityAudioContentPlaylistDetailBinding::inflate
) {

    private val viewModel: AudioContentPlaylistDetailViewModel by inject()

    private lateinit var loadingDialog: LoadingDialog
    private lateinit var adapter: AudioContentPlaylistDetailAdapter

    private var playlistId: Long = 0

    override fun onCreate(savedInstanceState: Bundle?) {
        playlistId = intent.getLongExtra(Constants.EXTRA_AUDIO_CONTENT_PLAYLIST_ID, 0)
        super.onCreate(savedInstanceState)

        if (playlistId <= 0) {
            showToast("잘못된 요청입니다.")
            finish()
        }

        bindData()
        viewModel.getPlaylistDetail(playlistId)
    }

    override fun setupView() {
        loadingDialog = LoadingDialog(this, layoutInflater)
        adapter = AudioContentPlaylistDetailAdapter()

        val recyclerView = binding.rvPlaylistDetail
        recyclerView.setHasFixedSize(true)
        recyclerView.layoutManager = LinearLayoutManager(
            applicationContext,
            LinearLayoutManager.VERTICAL,
            false
        )
        recyclerView.adapter = adapter

        binding.llPlay.setOnClickListener { }
        binding.llShuffle.setOnClickListener { }
    }

    @SuppressLint("SetTextI18n")
    private fun bindData() {
        viewModel.toastLiveData.observe(this) {
            it?.let { Toast.makeText(applicationContext, it, Toast.LENGTH_LONG).show() }
        }

        viewModel.isLoading.observe(this) {
            if (it) {
                loadingDialog.show(screenWidth, "")
            } else {
                loadingDialog.dismiss()
            }
        }

        viewModel.detailResponseLiveData.observe(this) {
            binding.tvDesc.text = it.desc
            binding.tvTitle.text = it.title
            binding.tvContentCount.text = " ${it.contentCount}개"
            binding.tvCreateDate.text = "만든 날짜 ${it.createdDate} "
            updateCoverImageLayout(imageUrlList = it.playlistCoverImageList)
        }
    }

    private fun updateCoverImageLayout(imageUrlList: List<String>) {
        val imageViews = listOf(
            binding.ivCover1,
            binding.ivCover2,
            binding.ivCover3,
            binding.ivCover4,
            binding.ivCover5,
            binding.ivCover6
        )

        imageViews.forEach { it.visibility = View.GONE }

        when (imageUrlList.size) {
            1, 2 -> {
                setImage(imageViews[0], imageUrlList[0])
            }

            3 -> {
                setImage(imageViews[1], imageUrlList[0])
                setImage(imageViews[2], imageUrlList[1])
                setImage(imageViews[3], imageUrlList[2])
            }

            4 -> {
                setImage(imageViews[1], imageUrlList[0])
                setImage(imageViews[2], imageUrlList[1])
                setImage(imageViews[4], imageUrlList[2])
                setImage(imageViews[5], imageUrlList[3])
            }
        }
    }

    private fun setImage(imageView: ImageView, imageUrl: String) {
        imageView.apply {
            visibility = View.VISIBLE
            this.load(imageUrl)
        }
    }
}
